@@ -114,9 +114,10 @@ ascat.aspcf = function(ASCATobj, selectsamples = 1:length(ASCATobj$samples), asc
           bafASPCF = NULL
           if(length(logRaveraged)<6) {
             logRASPCF = rep(mean(logRaveraged),length(logRaveraged))
-            bafASPCF = rep(ifelse(mean(bafselwins)>=0.5,mean(bafselwins),1-mean(bafselwins)),length(logRaveraged))
+            bafASPCF = rep(mean(bafselwinsmirrored),length(logRaveraged))
+            if ('isTargetedSeq' %in% names(ASCATobj) && ASCATobj$isTargetedSeq && bafASPCF[1]<=0.55) bafASPCF=rep(0.5,length(logRaveraged))
           } else {
-            PCFed = fastAspcf(logRaveraged,bafselwins,6,segmentlength)
+            PCFed = fastAspcf(logRaveraged,bafselwins,6,segmentlength,ASCATobj$isTargetedSeq)
             logRASPCF = PCFed$yhat1
             bafASPCF = PCFed$yhat2
           }
@@ -172,8 +173,9 @@ ascat.aspcf = function(ASCATobj, selectsamples = 1:length(ASCATobj$samples), asc
         if(length(homsegs)==3) {
           homsegs=t(as.matrix(homsegs))
         }
-        if(!is.null(homsegs)&&!is.na(homsegs)&&dim(homsegs)[1]!=0) {
+        if(!is.null(homsegs)&&dim(homsegs)[1]!=0) {
           for (i in 1:dim(homsegs)[1]) {
+            if (anyNA(homsegs[i,])) next
             # note that only the germline homozygous segment is resegmented, plus a bit extra (but this is NOT replaced)
             startpos = max(homsegs[i,2],startchr)
             endpos = min(homsegs[i,3],endchr)
@@ -307,7 +309,8 @@ predictGermlineHomozygousStretches = function(chr, hom) {
 # Whole chromosomes/chromosome arms wrapper function
 #
 
-fastAspcf <- function(logR, allB, kmin, gamma){
+fastAspcf <- function(logR, allB, kmin, gamma, isTargetedSeq){
+  if (is.null(isTargetedSeq)) isTargetedSeq=F
   
   N <- length(logR)
   w <- 1000 #w: windowsize
@@ -385,9 +388,9 @@ fastAspcf <- function(logR, allB, kmin, gamma){
       # if(sd3 < 1.8*sd2){
       mu <- 0
     }
+    if (isTargetedSeq && mu<=0.05) mu=0
     yhat2[frst[i]:last[i]] <- rep(mu+0.5,last[i]-frst[i]+1)
   }
-  
   return(list(yhat1=yhat1,yhat2=yhat2))
   
 }#end fastAspcf
